@@ -1,6 +1,8 @@
 package Devel::ebug::Backend::Plugin::ActionPoints;
+$Devel::ebug::Backend::Plugin::ActionPoints::VERSION = '0.57';
 use strict;
 use warnings;
+use File::Spec;
 
 sub register_commands {
   return (
@@ -11,6 +13,7 @@ sub register_commands {
   break_point_delete => { sub => \&break_point_delete, record => 1 },
   break_point_subroutine => { sub => \&break_point_subroutine, record => 1 },  
   watch_point => { sub => \&watch_point, record => 1 },
+  break_on_load => { sub => \&break_on_load },
   );
 }
 sub break_point {
@@ -106,7 +109,21 @@ sub set_break_point {
   return $line;
 }
 
+#set a break point on file loading
+sub break_on_load{
+  my($req, $context) = @_;
+  my $filename = $req->{filename};
+  
+  $DB::break_on_load{$filename} = 1;
 
+  if (!File::Spec->file_name_is_absolute( $filename )){
+      #add the absolute path
+    $filename = File::Spec->rel2abs( $filename);
+    $DB::break_on_load{$filename} = 1;
+  }
+       
+  return {};
+}
 
 
 1;
