@@ -1,5 +1,5 @@
 package Devel::ebug::Console;
-$Devel::ebug::Console::VERSION = '0.56';
+$Devel::ebug::Console::VERSION = '0.57';
 use strict;
 use warnings;
 use lib 'lib';
@@ -28,7 +28,7 @@ sub run {
   $ebug->backend($backend);
   $ebug->load;
 
-  my $codelines;
+  my $codelines = {};
 
   print "* Welcome to Devel::ebug $Devel::ebug::VERSION\n";
 
